@@ -1,7 +1,8 @@
 package App::Licensecheck;
 
 use utf8;
-use strictures;
+use strict;
+use warnings;
 use autodie;
 
 use version;
@@ -181,11 +182,11 @@ App::Licensecheck - functions for a simple license checker for source files
 
 =head1 VERSION
 
-Version v3.2.2
+Version v3.2.3
 
 =cut
 
-our $VERSION = version->declare('v3.2.2');
+our $VERSION = version->declare('v3.2.3');
 
 =head1 SYNOPSIS
 
